==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/confluent/kotlin/inputs/ListOrganizationRegionsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.confluent.kotlin.inputs

import com.pulumi.azurenative.confluent.inputs.ListOrganizationRegionsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property organizationName Organization resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property searchFilters Search filters for the request
 */
public data class ListOrganizationRegionsPlainArgs(
    public val organizationName: String,
    public val resourceGroupName: String,
    public val searchFilters: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.confluent.inputs.ListOrganizationRegionsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.confluent.inputs.ListOrganizationRegionsPlainArgs =
        com.pulumi.azurenative.confluent.inputs.ListOrganizationRegionsPlainArgs.builder()
            .organizationName(organizationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .searchFilters(
                searchFilters?.let({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [ListOrganizationRegionsPlainArgs].
 */
@PulumiTagMarker
public class ListOrganizationRegionsPlainArgsBuilder internal constructor() {
    private var organizationName: String? = null

    private var resourceGroupName: String? = null

    private var searchFilters: Map<String, String>? = null

    /**
     * @param value Organization resource name
     */
    @JvmName("hhxwoljstxmrgifv")
    public suspend fun organizationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.organizationName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("mjimcsycknenddxe")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Search filters for the request
     */
    @JvmName("dqcylfccanwagian")
    public suspend fun searchFilters(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.searchFilters = mapped
    }

    /**
     * @param values Search filters for the request
     */
    @JvmName("ofemgybibaykbqhi")
    public fun searchFilters(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.searchFilters = mapped
    }

    internal fun build(): ListOrganizationRegionsPlainArgs = ListOrganizationRegionsPlainArgs(
        organizationName = organizationName ?: throw PulumiNullFieldException("organizationName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        searchFilters = searchFilters,
    )
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/confluent/kotlin/inputs/ListOrganizationRegionsPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.confluent.kotlin.inputs

import com.pulumi.azurenative.confluent.inputs.ListOrganizationRegionsPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property organizationName Organization resource name
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property searchFilters Search filters for the request
 */
public data class ListOrganizationRegionsPlainArgs(
    public val organizationName: String,
    public val resourceGroupName: String,
    public val searchFilters: Map<String, String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.confluent.inputs.ListOrganizationRegionsPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.confluent.inputs.ListOrganizationRegionsPlainArgs =
        com.pulumi.azurenative.confluent.inputs.ListOrganizationRegionsPlainArgs.builder()
            .organizationName(organizationName.let({ args0 -> args0 }))
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .searchFilters(
                searchFilters?.let({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            ).build()
}

/**
 * Builder for [ListOrganizationRegionsPlainArgs].
 */
@PulumiTagMarker
public class ListOrganizationRegionsPlainArgsBuilder internal constructor() {
    private var organizationName: String? = null

    private var resourceGroupName: String? = null

    private var searchFilters: Map<String, String>? = null

    /**
     * @param value Organization resource name
     */
    @JvmName("demrdhgbdpbylagd")
    public suspend fun organizationName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.organizationName = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("hvvokkvksromroxm")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Search filters for the request
     */
    @JvmName("lrmwotjcpplkbbna")
    public suspend fun searchFilters(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> args0 })
        this.searchFilters = mapped
    }

    /**
     * @param values Search filters for the request
     */
    @JvmName("krrfjcpnpqksjlwy")
    public fun searchFilters(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.searchFilters = mapped
    }

    internal fun build(): ListOrganizationRegionsPlainArgs = ListOrganizationRegionsPlainArgs(
        organizationName = organizationName ?: throw PulumiNullFieldException("organizationName"),
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        searchFilters = searchFilters,
    )
}
